import { Injectable } from '@angular/core';
import { Observable, from,of } from 'rxjs';

import { DropdownQuestion } from './question-dropdown';
import { QuestionBase } from './question-base';
import { TextboxQuestion } from './question-textbox';
import { Question, Section } from '../models/question';

@Injectable()
export class QuestionService {
    fields : Question[] = [
        {
        controlType: 'dropdown',
        key: 'stars',
        label: 'How much would you like to rate us ?',
        options: [
            { key: '1', value: 'one' },
            { key: '2', value: 'two' },
            { key: '3', value: 'three' },
            { key: '4', value: 'four' },
            { key: '5', value: 'five' }
        ],
        value: '1',
        required: true,
        order: 4
    },
    {
        controlType: 'textbox',
        key: 'firstName',
        label: 'First name',
        value: 'Sreenivasa',
        order: 1,
    },
    {
        controlType: 'textbox',
        key: 'lastName',
        label: 'Last name',
        value: 'Rajiv',
        required: true,
        order: 2,
    },
    {
        controlType: 'textbox',
        key: 'emailAddress',
        label: 'Email',
        type: 'email',
        required: true,
        order: 3,
    },
    {
        controlType: 'textarea',
        key: 'feedback',
        label: 'Feedback',
        order: 5,
    }
];
    questions = [];
    arraySource = of(this.fields);

    // arraySource.subscribe((data)=>{

    // })

    getComplexQuestionFromApi(): Section[] {
        return [
            {
                heading: 'Details',
                name: 'details',
                css: 'row',
                columns: [
                    {
                        css: 'col-md col-sm',
                        questions: [
                            {
                                controlType: 'textbox',
                                key: 'firstName',
                                label: 'First name',
                                value: 'Sreenivasa',
                                order: 1,
                            },
                            {
                                controlType: 'textbox',
                                key: 'lastName',
                                label: 'Last name',
                                value: 'Rajiv',
                                required: true,
                                order: 2,
                            }
                        ]
                    }, {
                        css: 'col-md col-sm',
                        questions: [
                            {
                                controlType: 'textbox',
                                key: 'emailAddress',
                                label: 'Email',
                                type: 'email',
                                required: true,
                                order: 3,
                            },
                            {
                                controlType: 'textbox',
                                key: 'phoneNumber',
                                label: 'Phone number',
                                type: 'number',
                                required: true,
                                order: 4,
                            }
                        ]
                    },
                ]
            },
            {
                heading: 'Address',
                name: 'address',
                css: 'row',
                columns: [
                    {
                        css: 'col-md col-sm',
                        questions: [
                            {
                                controlType: 'textbox',
                                key: 'streetname',
                                label: 'Street',
                                order: 5,
                            }
                        ]
                    },
                    {
                        css: 'col-md col-sm',
                        questions: [
                            {
                                controlType: 'textbox',
                                key: 'city',
                                label: 'City',
                                order: 5,
                            }
                        ]
                    },
                    {
                        css: 'col-md col-sm',
                        questions: [
                            {
                                controlType: 'textbox',
                                key: 'state',
                                label: 'State',
                                order: 5,
                            }
                        ]
                    }
                ]
            },
            {
                heading: 'Feedback',
                name: 'feedback',
                css: 'row',
                columns: [
                    {
                        css: 'col-sm-6 col-md-6',
                        questions: [
                            {
                                controlType: 'textarea',
                                key: 'message',
                                label: 'Your message for us',
                                required: true,
                                order: 1,
                            },
                            {
                                controlType: 'dropdown',
                                key: 'stars',
                                label: 'How much would you like to rate us ?',
                                options: [
                                    { key: '1', value: 'one' },
                                    { key: '2', value: 'two' },
                                    { key: '3', value: 'three' },
                                    { key: '4', value: 'four' },
                                    { key: '5', value: 'five' }
                                ],
                                value: '1',
                                required: true,
                                order: 2
                            }
                        ]
                    }
                ]
            }
        ];
    }

      data:Observable<any>;
       
    getQuestionsFromApis(): Observable<Question[]> {
       
        return this.arraySource;
    }

    getQuestionsFromApi(): Question[] {
       
        return this.fields;
    }

    setFormQuestions(formQuestion:Question)
    {
        this.fields.push(formQuestion);
        console.log(this.fields);
    }

    setQuestions(questions) {
        this.questions = this.convertQuestions(questions);
    }


    getQuestions(): Observable<QuestionBase<any>[]> {
        return from(this.questions);
    }

    convertQuestions(questions: Question[]): QuestionBase<any>[] {

        const temp = [];

        for (const question of questions) {
            temp.push(this.generateQuestionBase(question));
        }

        // return temp.sort((a, b) => a.order - b.order);
        return temp;
    }

    generateQuestionBase(question: Question): QuestionBase<any> {
        switch (question.controlType) {
            case 'dropdown':
                return new DropdownQuestion(question);
            case 'textbox':
                return new TextboxQuestion(question);
            case 'textarea':
                return new TextboxQuestion(question);
            default:
                return new QuestionBase(question);
        }
    }
}
