import { Component, OnInit, Input, TemplateRef, ViewChild } from '@angular/core';
import { Section } from '../../models/question';
import { DragulaService } from 'ng2-dragula';
import { BsModalService } from 'ngx-bootstrap/modal';
import { BsModalRef } from 'ngx-bootstrap/modal/bs-modal-ref.service';
import { NgForm } from '@angular/forms';

@Component({
  selector: 'app-canvas',
  templateUrl: './canvas.component.html',
  styleUrls: ['./canvas.component.css'],
})
export class CanvasComponent implements OnInit {

  @Input() data: Section[] = [];

  SECTIONS = 'SECTIONS';
  bsModal: BsModalRef;
  @ViewChild('template') bsTemplate: TemplateRef<any>;

  index: number;

  constructor(private ds: DragulaService, private bms: BsModalService) { }

  ngOnInit() {
    this.ds.dropModel(this.SECTIONS)
      .subscribe(({ sourceModel, targetModel, item }) => {
        const index = targetModel.indexOf(item);
        this.openModal(item, targetModel, sourceModel);
      });
  }

  deleteSection(section) {
    const index = this.data.indexOf(section);
    if (index > -1) {
      this.data.splice(index, 1);
    }
  }

  openModal(item: any, targetModel: any, sourceModel: any) {
    if (sourceModel.indexOf(item) > -1) {
      return;
    }
    this.index = targetModel.indexOf(item);
    // this.data = targetModel;
    this.bsModal = this.bms.show(this.bsTemplate);
  }
  configureSection(modalForm: NgForm) {
    if (!modalForm.valid) {
      return false;
    }
    const value = modalForm.value;
    const section = this.data[this.index];
    section.heading = value.heading;
    section.name = value.name;
    section.columns = [];
    for (let i = 1; i <= value.column; i++) {
      section.columns.push({ css: 'col-sm col-md', questions: [] });
    }
    this.bsModal.hide();
    modalForm.reset();
  }

  cancelSection() {
    this.data.splice(this.index, 1);
    this.bsModal.hide();
  }

}
