import { Component, OnInit, OnDestroy } from '@angular/core';
import { QuestionService } from '../../dynamic-form/question.service';
import { DragulaService } from 'ng2-dragula';
import { Section, Column, Question } from '../../models/question';
import { Subscription } from 'rxjs';
import { map } from 'rxjs/operators';

@Component({
  selector: 'app-fields',
  templateUrl: './fields.component.html',
  styleUrls: ['./fields.component.css']
})
export class FieldsComponent implements OnInit, OnDestroy {

  sections: Section[] = [{
    name: 'section',
    css: 'row',
    heading: 'Section',
    columns: []
  }];
  columns: Column[] = [{
    css: 'col-md col-sm',
    questions: []
  }];
  questions: Question[] = [];

  subs = new Subscription();

  SECTIONS = 'SECTIONS';
  COLUMNS = 'COLUMNS';
  QUESTIONS = 'QUESTIONS';

  constructor(private qs: QuestionService, private ds: DragulaService) {
    
    this.qs.getQuestionsFromApis().subscribe(data=>{
      this.questions = data;
    })
    //this.questions = this.qs.getQuestionsFromApi
    this.ds.createGroup(this.QUESTIONS, {
      moves: (element, source, handle, sibling) => {
        if (handle.className.indexOf('child') >= 0 || handle.className.indexOf('fields') >= 0) {
          return true;
        }
        return false;
      },
      // copy: (el, source) => {
      //   return false;
      // },
    });
    this.ds.createGroup(this.SECTIONS, {
      moves: (element, source, handle, sibling) => {
        if (handle.className.indexOf('handle') >= 0 || handle.className.indexOf('fields') >= 0) {
          return true;
        }
        return false;
      },
      copy: (el, source) => {
        if (el.className.indexOf('fields') >= 0) {
          return true;
        }
        return false;
      },
      copyItem: (original) => {
        const dup = JSON.parse(JSON.stringify(original));
        dup.id = 'sectionCanvas' + (Number)(Math.random() * (2));
        return dup;
      }

    });
    this.ds.createGroup(this.COLUMNS, {
      moves: (element, source, handle, sibling) => {
        if ((element.className.indexOf('col-md col-sm') >= 0 && handle.className.indexOf('child') < 0)
          || handle.className.indexOf('fields') >= 0) {
          return true;
        }
        return false;
      },
      copy: (el, source) => {
        if (el.className.indexOf('fields') >= 0) {
          return true;
        }
        return false;
      },
      copyItem: (original) => {
        const dup = JSON.parse(JSON.stringify(original));
        return dup;
      }
  });

    // this.ds.createGroup(this.QUESTIONS, {
    //   copy: () => {
    //     return true;
    //   },
    //   copyItem: field => {
    //     return Object.assign({}, field);
    //   }
    // });

    // const _this = this;

    this.subs.add(this.ds.drop(this.SECTIONS)
      .subscribe(({ name, el, target, source, sibling }) => {
        // if (confirm('do you want to add column by default ?')) {
        //   _this.sections.push({ name: 'section', heading: 'Section', columns: [{ questions: [] }] });
        // }
      }));

  }

  ngOnInit() {
  }

  ngOnDestroy() {
    this.subs.unsubscribe();
  }

}
